#AutoIt3Wrapper_Au3Check_Parameters=-w 1 -w 2 -w 3 -w 4 -w 5 -w 6

; Script written by priester
;
; This script creates a splash-window with custom bitmap background, gif-progressbar, and information message to use as a wrapper for any other executable
; Parameters for the launched  application and splash-window taken from the ini-config file (default config-file is wrapper_config.ini)
; Syntax:
; SplashScreenApp = reads configuration from wrapper_config.ini in Current Directory
; SplashScreenApp "PathToConfigIni" = reads configuration from ini-config-file with full path PathToConfigIni
; SplashScreenApp "PathToConfigIni" "Param1" Param2" = pass additional parameters to the main Matlab executable
;
; This script uses GIFAnimation.au3 written by trancexx (trancexx at yahoo dot com)

; History:
; 27.09.2014 - v. 1.0


#include <GUIConstantsEx.au3>
#include <WindowsConstants.au3>
#include <MsgBoxConstants.au3>
#include <StaticConstants.au3>

#include <ColorConstants.au3>
#include <FontConstants.au3>

#include "GIFAnimation.au3"

;---------------------------------------------------
; Script parameters
;---------------------------------------------------
Local $vExeSkipTime=100 ; in seconds, time to wait for the application
Local $vMsgSkipTime=10  ; in seconds, time to show warning message
;
Local $config_file
If $CmdLine[0]==0 Then
$config_file="splash_config.ini"
Else
$config_file=$CmdLine[1]
EndIf
;
Local $sErrorIDconfig="Splash-wrapper: Config-file error"
;
Local $vParameters_str=""
;
;---------------------------------------------------
; Options
;---------------------------------------------------
;WinTitleMatchMode alters the method that is used to match window titles during search operations.
;1 = (default) Match the title from the start
;2 = Match any substring in the title
;3 = Exact title match
;4 = Advanced mode (retained for backwards compatibility only - see Window Titles & Text (Advanced))
;-1 to -4 = Case insensitive match according to the other type of match.
Local $vWinTitleMatchMode=1
;---------------------------------------------------
; Read ini-file for preferences
;---------------------------------------------------
Local $vExe_path, $sBackground_path, $sInfo_str
$sLoading_loop_path=""  ; no gif animation [default]
Local $vGui_width, $vGui_height
Local $sInfo_str_fontname="" ; default font
Local $vInfo_str_fontsize=10
Local $vInfo_str_clr = 0xFF3300 ; hex code
Local $vInfo_str_bgclr = $GUI_BKCOLOR_TRANSPARENT ;

Local $vLoading_loop_width  = -1 ;
Local $vLoading_loop_height = -1;
;
;The weight of the font in the range 0 through 1000. For example, 400 is normal and 700 is bold. If this value is zero, a default weight is used.
;The following values are defined for convenience.
;    $FW_DONTCARE = 0 (Use the default font weight)
;    $FW_THIN = 100
;    $FW_EXTRALIGHT = 200
;    $FW_LIGHT = 300
;    $FW_NORMAL = 400
;    $FW_MEDIUM = 500
;    $FW_SEMIBOLD = 600
;    $FW_BOLD = 700
;    $FW_EXTRABOLD = 800
;    $FW_HEAVY = 900
Local $vInfo_str_fontweight=$FW_NORMAL
;Font attributes, which can be a combination of the following added together:
;$GUI_FONTITALIC (2) = Italic
;$GUI_FONTUNDER (4) = Underlined
;$GUI_FONTSTRIKE (8) = Strike
; Or use 2+4 for Italic and Underlined
Local $vInfo_str_fontattrib=0
;
Local $vInfo_str_alignment=$SS_CENTER
;
Local $vInfo_string_shift=5
Local $vInfo_string_left_shift =0
Local $vInfo_string_right_shift=0

Local $vLoading_loop_shift_bottom=-1
;

;
; Executable
$vExe_path=IniRead($config_file, "Application", "exe_path", "NOTFOUND")
If $vexe_path=="NOTFOUND" Then
MsgBox($MB_ICONERROR, $sErrorIDconfig, "Can't find exe_path key in " & $config_file, $vMsgSkipTime)
Exit
EndIf
$vExe_Fig_Title=IniRead($config_file, "Application", "exe_fig_title", "NOTFOUND")
If $vExe_Fig_Title=="NOTFOUND" Then
MsgBox($MB_ICONERROR, $sErrorIDconfig, "Can't find exe_fig_title key in " & $config_file, $vMsgSkipTime)
Exit
EndIf
;
; $vWrapper_title=IniRead($config_file, "GUI", "wrapper_title", "NOTFOUND")
; If $vWrapper_title=="NOTFOUND" Then
; MsgBox($MB_ICONERROR, $sErrorIDconfig, "Can't find wrapper_title key in " & $config_file, $vMsgSkipTime)
; Exit
; EndIf
;
; GUI
$vGui_width =IniRead($config_file, "GUI", "gui_width", "NOTFOUND")
$vGui_height=IniRead($config_file, "GUI", "gui_height", "NOTFOUND")
;
$vBackground_path=IniRead($config_file, "GUI", "background_path", "NOTFOUND")
If $vBackground_path=="NOTFOUND" Then
MsgBox($MB_ICONERROR, $sErrorIDconfig, "Can't find background_path key in " & $config_file, $vMsgSkipTime)
Exit
EndIf
;
Local $vLoading_loop_path_val=IniRead($config_file, "GUI", "loading_loop_path", "NOTFOUND")
If $vLoading_loop_path_val=="NOTFOUND" Then
;MsgBox($MB_ICONERROR, $sErrorIDconfig, "Can't find loading_loop_path key in " & $config_file, $vMsgSkipTime)
Else
$vLoading_loop_path=$vLoading_loop_path_val
EndIf
;
Local $vLoading_loop_width_val=IniRead($config_file, "Gui", "loop_width", "NOTFOUND")
If $vLoading_loop_width_val=="NOTFOUND" Then
Else 
$vLoading_loop_width=$vLoading_loop_width_val
EndIf
;
Local $vLoading_loop_height_val=IniRead($config_file, "Gui", "loop_height", "NOTFOUND")
If $vLoading_loop_height_val=="NOTFOUND" Then
Else 
$vLoading_loop_height=$vLoading_loop_height_val
EndIf
;
$vInfo_str=IniRead($config_file, "GUI", "info_str", "NOTFOUND")
If $vInfo_str=="NOTFOUND" Then
MsgBox($MB_ICONERROR, $sErrorIDconfig, "Can't find info_str key in " & $config_file, $vMsgSkipTime)
Exit
EndIf

$vInfo_str=IniRead($config_file, "GUI", "info_str", "NOTFOUND")
If $vInfo_str=="NOTFOUND" Then
MsgBox($MB_ICONERROR, $sErrorIDconfig, "Can't find info_str key in " & $config_file, $vMsgSkipTime)
Exit
EndIf
;
Local $sInfo_str_fontname_val=IniRead($config_file, "Gui", "info_str_fontname", "NOTFOUND")
If $sInfo_str_fontname_val=="NOTFOUND" Then
Else 
$sInfo_str_fontname=$sInfo_str_fontname_val
EndIf
;
Local $sInfo_str_fontsize_val=IniRead($config_file, "Gui", "info_str_fontsize", "NOTFOUND")
If $sInfo_str_fontsize_val=="NOTFOUND" Then
Else 
$sInfo_str_fontsize=$sInfo_str_fontsize_val
EndIf
;
Local $vInfo_str_fontweight_val=IniRead($config_file, "Gui", "info_str_fontweight", "NOTFOUND")
If $vInfo_str_fontweight_val=="NOTFOUND" Then
Else 
$vInfo_str_fontweight=$vInfo_str_fontweight_val
EndIf
;
Local $vInfo_str_fontattrib_val=IniRead($config_file, "Gui", "info_str_fontattribute", "NOTFOUND")
If $vInfo_str_fontattrib_val=="NOTFOUND" Then
Else 
$vInfo_str_fontattrib=$vInfo_str_fontattrib_val
EndIf
;
Local $vInfo_str_alignment_val=IniRead($config_file, "Gui", "info_str_alignment", "NOTFOUND")
If $vInfo_str_alignment_val=="NOTFOUND" Then
Else 
$vInfo_str_alignment=$vInfo_str_alignment_val
EndIf
;
Local $vInfo_str_clr_val=IniRead($config_file, "Gui", "info_str_clr", "NOTFOUND")
If $vInfo_str_clr_val=="NOTFOUND" Then
Else 
$vInfo_str_clr=$vInfo_str_clr_val
EndIf
;
Local $vInfo_str_bgclr_val=IniRead($config_file, "Gui", "info_str_bgclr", "NOTFOUND")
If $vInfo_str_bgclr_val=="NOTFOUND" Then
Else 
$vInfo_str_bgclr=$vInfo_str_bgclr_val
EndIf
;
Local $vLoading_loop_shift_bottom_val=IniRead($config_file, "Gui", "loading_loop_shift_bottom", "NOTFOUND")
If $vLoading_loop_shift_bottom_val=="NOTFOUND" Then
Else 
$vLoading_loop_shift_bottom=$vLoading_loop_shift_bottom_val
EndIf
;
Local $vInfo_string_shift_val=IniRead($config_file, "Gui", "info_string_shift", "NOTFOUND")
If $vInfo_string_shift_val=="NOTFOUND" Then
Else 
$vInfo_string_shift=$vInfo_string_shift_val
EndIf
;
Local $vInfo_string_left_shift_val=IniRead($config_file, "Gui", "info_string_left_shift", "NOTFOUND")
If $vInfo_string_left_shift_val=="NOTFOUND" Then
Else 
$vInfo_string_left_shift=$vInfo_string_left_shift_val
EndIf
;
Local $vInfo_string_right_shift_val=IniRead($config_file, "Gui", "info_string_right_shift", "NOTFOUND")
If $vInfo_string_right_shift_val=="NOTFOUND" Then
Else 
$vInfo_string_right_shift=$vInfo_string_right_shift_val
EndIf
;
; Options
Local $vWinTitleMatchMode_val=IniRead($config_file, "Options", "WinTitleMatchMode", "NOTFOUND")
If $vWinTitleMatchMode_val=="NOTFOUND" Then
Else 
$vWinTitleMatchMode=$vWinTitleMatchMode_val
EndIf
;
Local $vExeSkipTime_val=IniRead($config_file, "Options", "exe_timeout", "NOTFOUND")
If $vExeSkipTime_val=="NOTFOUND" Then
Else 
$vExeSkipTime=$vExeSkipTime_val
EndIf
;
Local $vMsgSkipTime_val=IniRead($config_file, "Options", "msg_timeout", "NOTFOUND")
If $vMsgSkipTime_val=="NOTFOUND" Then
Else 
$vMsgSkipTime=$vMsgSkipTime_val
EndIf


;---------------------------------------------------
; GUI 
;---------------------------------------------------
;
Opt("GUICloseOnESC"      ,1) ; ESC to exit
Opt("MustDeclareVars"    ,1)
Opt("WinDetectHiddenText",0) 
Opt("WinTitleMatchMode"  ,$vWinTitleMatchMode) 

Global $sGifFile = $vLoading_loop_path
Global $sBGFile  = $vBackground_path

Global $aGIFDimension = _GIF_GetDimension($sGifFile)
Local $aBGDimension   = _GIF_GetDimension($sBGFile )

If $vGui_width=="NOTFOUND" Then
$vGui_width=$aBGDimension[0]
EndIf

If $vGui_height=="NOTFOUND" Then
$vGui_height=$aBGDimension[1]
EndIf

;Global $hGui = GUICreate($vWrapper_title, $vGui_width, $vGui_height, -1, -1,$WS_POPUP, $WS_EX_TOPMOST) ;$WS_OVERLAPPEDWINDOW,$WS_OVERLAPPEDWINDOW $WS_POPUP
Global $hGui = GUICreate("SplashWindowApp", $vGui_width, $vGui_height, -1, -1,$WS_POPUP, $WS_EX_TOPMOST) ;$WS_OVERLAPPEDWINDOW,$WS_OVERLAPPEDWINDOW $WS_POPUP
Local $aGuiPos = WinGetPos($hGui) 

;MsgBox($MB_SYSTEMMODAL, "Title", "$aGuiPos[0]=" & $aGIFDimension[1], 10)
; Background image
Global $hBG = _GUICtrlCreateGIF($sBGFile, "",1, 1, $vGui_width,  $vGui_height)
; Add Loading Loop
Local $vGif_width, $vGif_height
If $vLoading_loop_width<0 Then
$vGif_width =$aGIFDimension[0]
Else
$vGif_width =$vLoading_loop_width
EndIf
If $vLoading_loop_height<0 Then
$vGif_height =$aGIFDimension[1]
Else
$vGif_height =$vLoading_loop_height
EndIf

Local $vGif_x, $vGif_y
$vGif_x= ($aGuiPos[2]-$vGif_width)/2.0
If $vLoading_loop_shift_bottom<0 Then 
$vLoading_loop_shift_bottom=0.05*$aGuiPos[3]
EndIF
$vGif_y=  $aGuiPos[3]-$vGif_height-$vLoading_loop_shift_bottom
;
Global $hGIF = _GUICtrlCreateGIF($sGifFile, "",$vGif_x, $vGif_y, $vGif_width,$vGif_height)
;
; Add information String
local $vlab_x = $vInfo_string_left_shift
local $vlab_y=$vGif_y-30
; Split info_string, create $sNew_info_str with CRLF
Local $aInfoStringMulti = StringSplit($vInfo_str ,"\n",1)
local $i
Local $sNew_info_str=$aInfoStringMulti[1]
For $i = 2 To UBound($aInfoStringMulti) - 1
    $sNew_info_str=$sNew_info_str & @CRLF & $aInfoStringMulti[$i]
Next
;
;
If $vInfo_str_fontattrib==0 Then
GUISetFont($sInfo_str_fontsize, $vInfo_str_fontweight, $sInfo_str_fontname)
Else
GUISetFont($sInfo_str_fontsize, $vInfo_str_fontweight,$vInfo_str_fontattrib, $sInfo_str_fontname)
EndIf

Local $hLabel=GUICtrlCreateLabel($sNew_info_str,$vlab_x,$vlab_y,$aGuiPos[2]-$vInfo_string_left_shift-$vInfo_string_right_shift,-1,$vInfo_str_alignment) ; 
; If $vInfo_str_fontattrib==0 Then
; GUICtrlSetFont($hLabel, $sInfo_str_fontsize, $vInfo_str_fontweight, $sInfo_str_fontname)
; Else
; GUICtrlSetFont($hLabel, $sInfo_str_fontsize, $vInfo_str_fontweight,$vInfo_str_fontattrib, $sInfo_str_fontname)
; EndIf
GUICtrlSetColor($hLabel, $vInfo_str_clr)
;GUICtrlSetBkColor ($hLabel, $GUI_BKCOLOR_TRANSPARENT)
GUICtrlSetBkColor ($hLabel, $vInfo_str_bgclr)
;GUICtrlSetPos ($hLabel, $vlab_x,$vlab_y,$aGuiPos[2],-1 )
Local $aLabPos=ControlGetPos($hGui,"",$hLabel)
GUICtrlSetPos ($hLabel, $vlab_x,$vGif_y-$aLabPos[3]-$vInfo_string_shift,$aLabPos[2],$aLabPos[3]) 

;GUICtrlSetColor(-1, 0xff0000)
;GUICtrlSetFont(-1, 35)
;GUICtrlSetPos($hGIF, 0, 0)
;GUICtrlSetTip($hGIF, "My Splash Screen")

GUIRegisterMsg(15, "_Refresh"); WM_PAINT
GUISetState(@SW_SHOW, $hGui)

;MsgBox($MB_SYSTEMMODAL, "Title", "TEST", 10)

;---------------------------------------------------
; Run Application executable
;---------------------------------------------------
;MsgBox($MB_SYSTEMMODAL, "Title", "RunString is " & $vExe_path & " " & $CmdLine[0], 10)
If $CmdLine[0]==0 Then
Run($vExe_path)
Else
; Create parameters string
$vParameters_str="""" & $CmdLine[2] & """"
For $i = 3 To UBound($CmdLine) - 1
    $vParameters_str=$vParameters_str & " " & """" & $CmdLine[$i] & """"
Next
;MsgBox($MB_SYSTEMMODAL, "Title", "Param string to Application is " & $vParameters_str, 10)
Run($vExe_path & " " & $vParameters_str)
EndIf

Local $hWnd=WinWait("[TITLE:" & $vExe_Fig_Title & "]", "", $vExeSkipTime)
If $hWnd Then
	GUIDelete($hGui)
;	WinSetOnTop($hWnd,"",1) 
    WinActivate($hWnd) 
    Exit
Else
	MsgBox($MB_SYSTEMMODAL, "Wrapper error", "Can't run " & $vExe_path & " or can't find window with title '" & $vExe_Fig_Title & "'" , $vMsgSkipTime)
	GUIDelete($hGui)
    Exit
Endif

; Loop until the user exits.
While 1
    Switch GUIGetMsg()
      Case $GUI_EVENT_CLOSE
           ExitLoop
    EndSwitch
WEnd

;While  1
;	Switch GUIGetMsg()
;		Case -3
;			Exit
;	EndSwitch
;WEnd

Func _Refresh($hWnd, $iMsg, $wParam, $lParam)
	#forceref $hWnd, $iMsg, $wParam, $lParam
	_GIF_RefreshGIF($hGIF)
EndFunc   ;==>_Refresh